function Z = internal_stridedadd(X, strideX, Y, strideY)
% This function is undocumented and may change in a future release.

%   Z = internal_stridedadd(X, strideX, Y, strideY)
%   Compute the addition X(1:strideX(1):end, 1:strideX(2):end, ...) + 
%       Y(1:strideY(1):end, 1:strideY(2):end, ...)
%
%   Inputs:
%     X               numeric array
%     strideX         vector of positive integers
%     Y               numeric array
%     strideY         vector of positive integers
%
%   Outputs:
%     Z               numeric array

%   Copyright 2022 The MathWorks, Inc.

Z = parallel.internal.gpu.stridedAdd(X, strideX, Y, strideY);

end